#
# spec file for package python-blue
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without libalternatives
Name:           python-blue
Version:        0.9.1
Release:        7.1
Summary:        A code formatter written in, and written for Python
License:        MIT
URL:            https://github.com/grantjenks/blue
Source:         https://github.com/grantjenks/blue/archive/v%{version}.tar.gz#/blue-%{version}.tar.gz
# PATCH-FIX-OPENSUSE unpin-tomli.patch -- gh#grantjenks/blue#66
Patch1:         unpin-tomli.patch
# PATCH-FIX-UPSTREAM flake8-v6-compatibility.patch -- gh#grantjenks/blue#96
Patch2:         flake8-v6-compatibility.patch
# PATCH-FIX-OPENSUSE black-24.1.patch -- gh#grantjenks/blue#97
Patch3:         black-24.1.patch
# PATCH-FIX-OPENSUSE black-25.1.patch -- gh#grantjenks/blue#106
Patch4:         black-25.1.patch
BuildRequires:  %{python_module Sphinx}
BuildRequires:  %{python_module base >= 3.6}
BuildRequires:  %{python_module black >= 21.7}
BuildRequires:  %{python_module flake8 >= 3.8}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  alts
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       alts
Requires:       python-black >= 24.1
BuildArch:      noarch
# SECTION doc and test requirements
BuildRequires:  %{python_module Sphinx}
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
Black is a code formatter written in Python, and reformats Python 2.x
and 3.x code.

Black reformats entire files in place. It is not configurable. It
does not take previous formatting into account. The coding style
enforced is a PEP-8 subset, adheres to PEP-257, and otherwise passes
the rules of the "pycodestyle" checker. Black skips over blocks that
start and end with "# fmt: off" and "# fmt: on", respectively. It
also recognizes YAPF's block comments to the same effect.

%package -n python-blue-doc
Summary:        Documentation files for %{name}
Provides:       %{python_module foo-doc = %{version}}

%description -n python-blue-doc
HTML Documentation and examples for %{name}.

%prep
%autosetup -p1 -n blue-%{version}

# avoid pytest addopts for coverage checks
sed -i '/--cov/d' tox.ini

%build
%pyproject_wheel
%make_build -C docs html

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/blue
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# gh#grantjenks/blue#72
%pytest -k 'not (test_good_dirs or test_bad_dirs)'

%pre
%python_libalternatives_reset_alternative blue

%files %{python_files}
%doc README.rst
%license LICENSE
%python_alternative %{_bindir}/blue
%{python_sitelib}/blue
%{python_sitelib}/blue-%{version}.dist-info

%files -n python-blue-doc
%doc docs/_build/html

%changelog
* Tue Jun 17 2025 Markéta Machová <mmachova@suse.com>
- Convert to libalternatives
* Fri Jun  6 2025 Steve Kowalik <steven.kowalik@suse.com>
- Switch to pyproject macros.
- Simplify docs build.
* Mon Mar 10 2025 Markéta Machová <mmachova@suse.com>
- Add black-25.1.patch to support changes in black 25.1
* Tue Feb  6 2024 Daniel Garcia <daniel.garcia@suse.com>
- Remove black-23.3.patch and add black-24.1.patch to support latest
  version of python-black.
* Wed Nov 22 2023 Daniel Garcia <daniel.garcia@suse.com>
- Make compatible with latest python-flake8 and python-black
  bsc#1217371
  - Add patch flake8-v6-compatibility.patch, gh#grantjenks/blue#96
  - Remove patch flake8-v5-compatibility.patch
  - Refresh patch python-blue.changes
* Thu May  4 2023 Daniel Garcia <daniel.garcia@suse.com>
- Add black-23.3.patch to make it compatible with latest python-black
  version. gh#grantjenks/blue#97
* Sat Jan 28 2023 Dirk Müller <dmueller@suse.com>
- update to 0.9.1:
  * blue is incompatible with flake8 v5 (GH#78) due to changes in the way
    flake8 parses its config files. For now, pin the flake8 dependency <5.0.0
  * Add support for testing against Python 3.10 and 3.11 in tox.ini, and fix an
    incompatibility with the rstcheck command line.
  * Bump copyright years.
- drop unpin-black.patch (obsolete)
- update flake8-v5-compatibility.patch to unpin flake8 again
* Mon Sep 19 2022 Daniel Garcia <daniel.garcia@suse.com>
- Add flake8-v5-compatibility.patch wich makes it work with flake8 v5
  gh#grantjenks/blue#78
* Wed May  4 2022 Matej Cepl <mcepl@suse.com>
- Upgrade to 0.9.0:
  - Fix test suite failures due to a confluence of problems
  - Upgrade dependency on Black to 22.1.0 to support Python 3.10
  - Add link to demo site at https://iblueit.dev
* Sat Apr 23 2022 Matej Cepl <mcepl@suse.com>
- Update unpin-tomli.patch to work with the current black package.
- Skip failing tests (gh#grantjenks/blue#72)
* Sat Mar 19 2022 Ben Greiner <code@bnavigator.de>
- Update to 0.8.0
  * Fix compatibility with flake8 v4 (GH#58)
- Drop support-new-flake8.patch fixed upstream
- Add unpin-black.patch and unpin-tomli.patch
- Clean requirements
* Wed Jan 12 2022 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.7.0:
  * Upgrade dependency on black to 21.7b0
- Add patch support-new-flake8.patch:
  * Support backwards incompatiable changes with flake8 4.0
* Wed Mar 17 2021 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.6.0:
  * Add bullet about default line length of 79 characters
  * Run blue over docs/ directory
  * Fix formatting in docs/conf.py
  * Preserve whitespace before hash mark on hanging comments (#31)
  * Use flake8 to parse project and user configs for blue
  * Patch the config param's callback
  * Fixes for static analysis
  * Format keys for Click's default_map
  * Add pytest for testing
  * Format tests/test_blue.py in blue and bluecheck commands
  * Add tests for config parsing
  * Update docs requirements to match setup.py
  * Add note to README and changelog.
  * Fix --version option handling and add test cases
  * Move coverage switches on pytest to separate sections
* Mon Jan 18 2021 Matej Cepl <mcepl@suse.com>
- Upgrade to 0.5.2:
  - fixed building of documentation (gh#grantjenks/blue#26)
* Sun Jan 17 2021 Matej Cepl <mcepl@suse.com>
- Initial packaging effort for blue 0.5.1
